pub enum ResponseErrorKind {
UnexpectedCommand(u8),
Nak(Nak),
}Expand description
The kinds of errors that may be interpreted from a DAC response.
Variants
UnexpectedCommand(u8)
The response was to a command that was unexpected.
Nak(Nak)
The DAC responded with a NAK.