pub struct IldaPlaybackFlags { /* private fields */ }Expand description
If the data source is ILDA playback via SD, the following flags are used.
Implementations
Sourceimpl IldaPlaybackFlags
impl IldaPlaybackFlags
pub const PLAYING: IldaPlaybackFlags
pub const REPEAT: IldaPlaybackFlags
Sourcepub const fn empty() -> IldaPlaybackFlags
pub const fn empty() -> IldaPlaybackFlags
Returns an empty set of flags
Sourcepub const fn all() -> IldaPlaybackFlags
pub const fn all() -> IldaPlaybackFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u16) -> Option<IldaPlaybackFlags>
pub fn from_bits(bits: u16) -> Option<IldaPlaybackFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u16) -> IldaPlaybackFlags
pub const fn from_bits_truncate(bits: u16) -> IldaPlaybackFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u16) -> IldaPlaybackFlags
pub const unsafe fn from_bits_unchecked(bits: u16) -> IldaPlaybackFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: IldaPlaybackFlags) -> bool
pub const fn intersects(&self, other: IldaPlaybackFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: IldaPlaybackFlags) -> bool
pub const fn contains(&self, other: IldaPlaybackFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: IldaPlaybackFlags)
pub fn insert(&mut self, other: IldaPlaybackFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: IldaPlaybackFlags)
pub fn remove(&mut self, other: IldaPlaybackFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: IldaPlaybackFlags)
pub fn toggle(&mut self, other: IldaPlaybackFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: IldaPlaybackFlags, value: bool)
pub fn set(&mut self, other: IldaPlaybackFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.