pub struct PlaybackFlags { /* private fields */ }Expand description
If the light engine is Ready, this will be 0.
Implementations
Sourceimpl PlaybackFlags
impl PlaybackFlags
Sourcepub const SHUTTER_OPEN: PlaybackFlags
pub const SHUTTER_OPEN: PlaybackFlags
Describes the state of the shutter.
Sourcepub const UNDERFLOWED: PlaybackFlags
pub const UNDERFLOWED: PlaybackFlags
Set if the last stream ended with underflow rather than a Stop.
Sourcepub const EMERGENCY_STOP: PlaybackFlags
pub const EMERGENCY_STOP: PlaybackFlags
Set if the last stream ended because the E-Stop state was entered.
This is reset to zero by the Prepare command.
Sourcepub const fn empty() -> PlaybackFlags
pub const fn empty() -> PlaybackFlags
Returns an empty set of flags
Sourcepub const fn all() -> PlaybackFlags
pub const fn all() -> PlaybackFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u16) -> Option<PlaybackFlags>
pub fn from_bits(bits: u16) -> Option<PlaybackFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u16) -> PlaybackFlags
pub const fn from_bits_truncate(bits: u16) -> PlaybackFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u16) -> PlaybackFlags
pub const unsafe fn from_bits_unchecked(bits: u16) -> PlaybackFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: PlaybackFlags) -> bool
pub const fn intersects(&self, other: PlaybackFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: PlaybackFlags) -> bool
pub const fn contains(&self, other: PlaybackFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: PlaybackFlags)
pub fn insert(&mut self, other: PlaybackFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: PlaybackFlags)
pub fn remove(&mut self, other: PlaybackFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: PlaybackFlags)
pub fn toggle(&mut self, other: PlaybackFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: PlaybackFlags, value: bool)
pub fn set(&mut self, other: PlaybackFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.