DacPoint

Struct DacPoint 

#[repr(C)]
pub struct DacPoint { pub control: u16, pub x: i16, pub y: i16, pub r: u16, pub g: u16, pub b: u16, pub i: u16, pub u1: u16, pub u2: u16, }
Values are full-scale.

E.g. for all color channels, 65535 is full output while 0 is no output.

Fields

control: u16

A set of bit fields. The following fields are defined:

  • 15: Change point rate. If this bit is set and there are any values in the point rate change buffer a new rate is read out of the buffer and set as the current playback rate. If the buffer is empty, the point rate is not changed.

All other bits are reserved for future expansion to support extra TTL outputs, etc.

x: i16

-32768 is the start along the x axis (left-most point). 32767 is the end along the x axis (right-most point).

y: i16

-32768 is the start along the y axis (bottom-most point). 32767 is the end along the y axis (top-most point).

r: u16

0 is no red. 65535 is full red.

g: u16

0 is no green. 65535 is full green.

b: u16

0 is no blue. 65535 is full blue.

i: u16u1: u16u2: u16