#[repr(C)]pub struct DacResponse {
pub response: u8,
pub command: u8,
pub dac_status: DacStatus,
}Expand description
A response from a DAC.
Fields
response: u8See the DacResponse associated constants for the possible values for this field.
command: u8In the case of ACK/NAK responses, this echoes back the command to which the response is sent.
Commands are always sent in order, so this field exists for sanity-checking on the host-side.
dac_status: DacStatusThe current status of the DAC.
Implementations
Sourceimpl DacResponse
impl DacResponse
Sourcepub const NAK_FULL: u8 = 0x46
pub const NAK_FULL: u8 = 0x46
The write command could not be performed because there was not enough buffer space when it was received.
Sourcepub const NAK_INVALID: u8 = 0x49
pub const NAK_INVALID: u8 = 0x49
The command contained an invalid command byte or parameters.
Sourcepub const NAK_STOP_CONDITION: u8 = 0x21
pub const NAK_STOP_CONDITION: u8 = 0x21
An emergency-stop condition still exists.