pub enum Command<'a> {
PrepareStream(PrepareStream),
Begin(Begin),
PointRate(PointRate),
Data(Data<'a>),
Stop(Stop),
EmergencyStop(EmergencyStop),
ClearEmergencyStop(ClearEmergencyStop),
Ping(Ping),
}Expand description
A command whose kind is determined at runtime.
This is particularly useful when Reading a command from bytes or from a TCP stream. The ReadFromBytes implementation will automatically determine the kind by reading the first byte.
Variants
PrepareStream(PrepareStream)
Begin(Begin)
PointRate(PointRate)
Data(Data<'a>)
Stop(Stop)
EmergencyStop(EmergencyStop)
ClearEmergencyStop(ClearEmergencyStop)
Ping(Ping)