Types and constants that precisely match the specification.
Re-exports
pub use self::command::Command;
Modules
- command
- When a host first connects to the device, the device immediately sends it a status reply as if the host had sent a ping packet. The host sends to the device a series of commands. All commands receive a response from the DAC.
Structs
- DacBroadcast
- Regardless of the data source being used, each DAC broadcasts a status/ID datagram over UDP to its local network’s broadcast address once per second.
- DacPoint
- Values are full-scale.
- DacResponse
- A response from a DAC.
- DacStatus
- Periodically, and as part of ACK packets, the DAC sends its current playback status to the host.
Constants
- BROADCAST_
PORT - The DAC sends UDP broadcast messages on port 7654.
- COMMUNICATION_
PORT - Communication with the DAC happens over TCP on port 7765.
Traits
- Read
Bytes - A trait for reading any of the Ether Dream protocol types from little-endian bytes.
- Read
From Bytes - Protocol types that may be read from little endian bytes.
- Size
Bytes - Types that have a constant size when written to or read from bytes.
- Write
Bytes - A trait for writing any of the Ether Dream protocol types to little-endian bytes.
- Write
ToBytes - Protocol types that may be written to little endian bytes.