#[repr(C)]pub struct DacBroadcast {
pub mac_address: [u8; 6],
pub hw_revision: u16,
pub sw_revision: u16,
pub buffer_capacity: u16,
pub max_point_rate: u32,
pub dac_status: DacStatus,
}Expand description
Regardless of the data source being used, each DAC broadcasts a status/ID datagram over UDP to its local network’s broadcast address once per second.
Fields
mac_address: [u8; 6]The unique hardware identifier for the DAC.
hw_revision: u16This field is undocumented in the official protocol but seems to represent a version number for the hardware in use by the DAC.
sw_revision: u16This field is undocumented in the official protocol but seems to represent the version of
the protocol implementation. As of writing this, this is hardcoded as 2 in the original
source.
buffer_capacity: u16The DAC’s maximum buffer capacity for storing points that are yet to be converted to output.
As of writing this, this is hardcoded to 1800 in the original DAC source code.
max_point_rate: u32The DAC’s maximum point rate.
As of writing this, this is hardcoded to 100_000 in the original DAC source code.
dac_status: DacStatusThe current status of the DAC.