#[repr(C)]pub struct DacPoint {
pub control: u16,
pub x: i16,
pub y: i16,
pub r: u16,
pub g: u16,
pub b: u16,
pub i: u16,
pub u1: u16,
pub u2: u16,
}Expand description
Values are full-scale.
E.g. for all color channels, 65535 is full output while 0 is no output.
Fields
control: u16A set of bit fields. The following fields are defined:
15: Change point rate. If this bit is set and there are any values in the point rate change buffer a new rate is read out of the buffer and set as the current playback rate. If the buffer is empty, the point rate is not changed.
All other bits are reserved for future expansion to support extra TTL outputs, etc.
x: i16-32768 is the start along the x axis (left-most point). 32767 is the end along the x axis (right-most point).
y: i16-32768 is the start along the y axis (bottom-most point). 32767 is the end along the y axis (top-most point).
r: u160 is no red. 65535 is full red.
g: u160 is no green. 65535 is full green.
b: u160 is no blue. 65535 is full blue.
i: u16u1: u16u2: u16Trait Implementations
Sourceimpl ReadFromBytes for DacPoint
impl ReadFromBytes for DacPoint
Sourcefn read_from_bytes<R: ReadBytesExt>(reader: R) -> Result<Self>
fn read_from_bytes<R: ReadBytesExt>(reader: R) -> Result<Self>
Read the command from bytes.
Sourceimpl WriteToBytes for DacPoint
impl WriteToBytes for DacPoint
Sourcefn write_to_bytes<W: WriteBytesExt>(&self, writer: W) -> Result<()>
fn write_to_bytes<W: WriteBytesExt>(&self, writer: W) -> Result<()>
Write the command to bytes.
impl Copy for DacPoint
impl Eq for DacPoint
impl StructuralPartialEq for DacPoint